package com.phm.manage.mapper;

import com.phm.manage.domain.ImportExportLog;

import java.util.List;

/**
 * 导入导出日志;Mapper接口
 *
 * @author phm
 * @date 2023-08-22
 */
public interface ImportExportLogMapper {
    /**
     * 查询导入导出日志;
     *
     * @param id 导入导出日志;主键
     * @return 导入导出日志;
     */
    public ImportExportLog selectImportExportLogById(Long id);

    /**
     * 查询导入导出日志;列表
     *
     * @param importExportLog 导入导出日志;
     * @return 导入导出日志;集合
     */
    public List<ImportExportLog> selectImportExportLogList(ImportExportLog importExportLog);

    /**
     * 新增导入导出日志;
     *
     * @param importExportLog 导入导出日志;
     * @return 结果
     */
    public int insertImportExportLog(ImportExportLog importExportLog);

    /**
     * 修改导入导出日志;
     *
     * @param importExportLog 导入导出日志;
     * @return 结果
     */
    public int updateImportExportLog(ImportExportLog importExportLog);

    /**
     * 删除导入导出日志;
     *
     * @param id 导入导出日志;主键
     * @return 结果
     */
    public int deleteImportExportLogById(Long id);

    /**
     * 批量删除导入导出日志;
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteImportExportLogByIds(Long[] ids);
}
